=========
GreedyBFS
=========


.. image:: https://img.shields.io/pypi/v/greedybfs.svg
        :target: https://pypi.python.org/pypi/greedybfs

.. image:: https://img.shields.io/travis/chinmayshah99/greedybfs.svg
        :target: https://travis-ci.org/chinmayshah99/greedybfs




Python Package for Implementation of Greedy BFS algorithm


* Free software: MIT license


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
